***************
Prerequisites
***************

- Python3
- pip

********
Install
********

pip
====
Preferred method

Install
--------

.. code:: sh

    pip install psprint


Update
-------

.. code:: sh

    pip install -U psprint


Uninstall
----------

.. code:: sh

    pip uninstall -y psprint



`pspman <https://github.com/pradyparanjpe/pspman>`__
=====================================================

(Linux only)

For automated management: updates, etc


Install
--------

.. code:: sh

   pspman -s -i https://github.com/pradyparanjpe/psprint.git



Update
-------

.. code:: sh

    pspman


*That's it.*


Uninstall
----------

Remove installation:

.. code:: sh

    pspman -s -d psprint

